#ifndef MAEMOAPPLICATION_H
#define MAEMOAPPLICATION_H

#include <QObject>


class MaemoApplication : public QObject {
    Q_OBJECT

    public:
        // constructors
        MaemoApplication ();
        MaemoApplication (QString,QString,QString, QString _rating=QString(""),QString _downloads="",QString _comments="",QString _version="",QString _pre="",QString _bpre="");
        MaemoApplication (QString);

        //setting parameters
        void setUid (QString _uid);
        void setTitle (QString _title);
        void setName (QString _name);
        void setVersion (QString _version);
        void setRating (QString _rating);
        void setDownloads (QString _downloads);
        void setComments (QString _comments);
        void setPreview (QString _pre);
        void setBigPreview (QString _bpre);

        //getting parameters
        QString getComments ();
        QString getUid ();
        QString getName ();
        QString getTitle ();
        QString getVersion ();
        QString getRating ();
        QString getDownloads ();
        QString getPreview ();
        QString getBigPreview ();

        //output as QString
        QString toString ();

    private:
            QString name;
            QString uid;
            QString rating;
            QString downloads;
            QString comments;
            QString version;
            QString title;
            QString preview;
            QString bigPreview;

 };

#endif // MAEMOAPPLICATION_H
